@@ -2,7 +2,7 @@ package TestChained::Controller::Root;
 use Moose;
 use namespace::autoclean;
 
-BEGIN { extends 'Catalyst::Controller::ActionRole' };
+BEGIN { extends 'Catalyst::Controller' };
 
 my $msg = '';
 
